==> epath-location-1.2.2-sources.jar: com/shitu/location/epathmap/model/parse/MapData.java <==
package com.shitu.location.epathmap.model.parse;

/**
 * author:lfei
 */
public class MapData {


    /**
     * objectId : lGaWCUtqoj
     * name : 广州市妇女儿童医疗中心
     * picture : http://ipsmap.oss-cn-shanghai.aliyuncs.com/%E5%B9%BF%E5%A6%87%E5%84%BF.png
     * buildingId : 58ca7cb413960a0d09830ae2
     * token : 9f09bb39bfe949b18defcf2d4326b34f
     * floorNumber : 1
     * floorName : 1
     * zoom : 18
     * angle : -3
     * powerThreshold : -100
     * inToOut : 1
     * outToIn : 2
     * gpsFloorlayer : 1
     * navigationZoom : 21
     * lat : 23.1276122
     * lng : 113.3147454
     */

    private String objectId;
    private String name;
    private String title;
    private String picture;
    private String buildingId;
    private String token;
    private int floorNumber;
    private String floorName;
    private double zoom;
    private double angle;
    private int powerThreshold;
    private int inToOut;
    private int outToIn;
    private int gpsFloorlayer;
    private double navigationZoom;
    private double lat;
    private double lng;
    private long markerId;
    private String districtName;
    private boolean selected;

    public String getObjectId() {
        return objectId;
    }

    public void setObjectId(String objectId) {
        this.objectId = objectId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getPicture() {
        return picture;
    }

    public void setPicture(String picture) {
        this.picture = picture;
    }

    public String getBuildingId() {
        return buildingId;
    }

    public void setBuildingId(String buildingId) {
        this.buildingId = buildingId;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public int getFloorNumber() {
        return floorNumber;
    }

    public void setFloorNumber(int floorNumber) {
        this.floorNumber = floorNumber;
    }

    public String getFloorName() {
        return floorName;
    }

    public void setFloorName(String floorName) {
        this.floorName = floorName;
    }

    public double getZoom() {
        return zoom;
    }

    public void setZoom(double zoom) {
        this.zoom = zoom;
    }

    public double getAngle() {
        return angle;
    }

    public void setAngle(double angle) {
        this.angle = angle;
    }

    public int getPowerThreshold() {
        return powerThreshold;
    }

    public void setPowerThreshold(int powerThreshold) {
        this.powerThreshold = powerThreshold;
    }

    public int getInToOut() {
        return inToOut;
    }

    public void setInToOut(int inToOut) {
        this.inToOut = inToOut;
    }

    public int getOutToIn() {
        return outToIn;
    }

    public void setOutToIn(int outToIn) {
        this.outToIn = outToIn;
    }

    public int getGpsFloorlayer() {
        return gpsFloorlayer;
    }

    public void setGpsFloorlayer(int gpsFloorlayer) {
        this.gpsFloorlayer = gpsFloorlayer;
    }

    public double getNavigationZoom() {
        return navigationZoom;
    }

    public void setNavigationZoom(double navigationZoom) {
        this.navigationZoom = navigationZoom;
    }

    public double getLat() {
        return lat;
    }

    public void setLat(double lat) {
        this.lat = lat;
    }

    public double getLng() {
        return lng;
    }

    public void setLng(double lng) {
        this.lng = lng;
    }

    public long getMarkerId() {
        return markerId;
    }

    public void setMarkerId(long markerId) {
        this.markerId = markerId;
    }

    public String getDistrictName() {
        return districtName;
    }

    public void setDistrictName(String districtName) {
        this.districtName = districtName;
    }

    public boolean isSelected() {
        return selected;
    }

    public void setSelected(boolean selected) {
        this.selected = selected;
    }

    @Override
    public String toString() {
        return "MapData{" +
                "objectId='" + objectId + '\'' +
                ", name='" + name + '\'' +
                ", title='" + title + '\'' +
                ", picture='" + picture + '\'' +
                ", buildingId='" + buildingId + '\'' +
                ", token='" + token + '\'' +
                ", floorNumber=" + floorNumber +
                ", floorName='" + floorName + '\'' +
                ", zoom=" + zoom +
                ", angle=" + angle +
                ", powerThreshold=" + powerThreshold +
                ", inToOut=" + inToOut +
                ", outToIn=" + outToIn +
                ", gpsFloorlayer=" + gpsFloorlayer +
                ", navigationZoom=" + navigationZoom +
                ", lat=" + lat +
                ", lng=" + lng +
                ", markerId=" + markerId +
                ", districtName='" + districtName + '\'' +
                ", selected=" + selected +
                '}';
    }
}

==> epath-location-1.2.8-sources.jar: com/shitu/location/epathmap/model/parse/MapData.java <==
package com.shitu.location.epathmap.model.parse;

/**
 * author:lfei
 */
public class MapData {


    /**
     * objectId : lGaWCUtqoj
     * name : 广州市妇女儿童医疗中心
     * picture : http://epath.oss-cn-shanghai.aliyuncs.com/%E5%B9%BF%E5%A6%87%E5%84%BF.png
     * buildingId : 58ca7cb413960a0d09830ae2
     * token : 9f09bb39bfe949b18defcf2d4326b34f
     * floorNumber : 1
     * floorName : 1
     * zoom : 18
     * angle : -3
     * powerThreshold : -100
     * inToOut : 1
     * outToIn : 2
     * gpsFloorlayer : 1
     * navigationZoom : 21
     * lat : 23.1276122
     * lng : 113.3147454
     */

    private String objectId;
    private String name;
    private String title;
    private String picture;
    private String buildingId;
    private String token;
    private int floorNumber;
    private String floorName;
    private double zoom;
    private double angle;
    private int powerThreshold;
    private int inToOut;
    private int outToIn;
    private int gpsFloorlayer;
    private double navigationZoom;
    private double lat;
    private double lng;
    private long markerId;
    private String districtName;
    private boolean selected;

    public String getObjectId() {
        return objectId;
    }

    public void setObjectId(String objectId) {
        this.objectId = objectId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getPicture() {
        return picture;
    }

    public void setPicture(String picture) {
        this.picture = picture;
    }

    public String getBuildingId() {
        return buildingId;
    }

    public void setBuildingId(String buildingId) {
        this.buildingId = buildingId;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }

    public int getFloorNumber() {
        return floorNumber;
    }

    public void setFloorNumber(int floorNumber) {
        this.floorNumber = floorNumber;
    }

    public String getFloorName() {
        return floorName;
    }

    public void setFloorName(String floorName) {
        this.floorName = floorName;
    }

    public double getZoom() {
        return zoom;
    }

    public void setZoom(double zoom) {
        this.zoom = zoom;
    }

    public double getAngle() {
        return angle;
    }

    public void setAngle(double angle) {
        this.angle = angle;
    }

    public int getPowerThreshold() {
        return powerThreshold;
    }

    public void setPowerThreshold(int powerThreshold) {
        this.powerThreshold = powerThreshold;
    }

    public int getInToOut() {
        return inToOut;
    }

    public void setInToOut(int inToOut) {
        this.inToOut = inToOut;
    }

    public int getOutToIn() {
        return outToIn;
    }

    public void setOutToIn(int outToIn) {
        this.outToIn = outToIn;
    }

    public int getGpsFloorlayer() {
        return gpsFloorlayer;
    }

    public void setGpsFloorlayer(int gpsFloorlayer) {
        this.gpsFloorlayer = gpsFloorlayer;
    }

    public double getNavigationZoom() {
        return navigationZoom;
    }

    public void setNavigationZoom(double navigationZoom) {
        this.navigationZoom = navigationZoom;
    }

    public double getLat() {
        return lat;
    }

    public void setLat(double lat) {
        this.lat = lat;
    }

    public double getLng() {
        return lng;
    }

    public void setLng(double lng) {
        this.lng = lng;
    }

    public long getMarkerId() {
        return markerId;
    }

    public void setMarkerId(long markerId) {
        this.markerId = markerId;
    }

    public String getDistrictName() {
        return districtName;
    }

    public void setDistrictName(String districtName) {
        this.districtName = districtName;
    }

    public boolean isSelected() {
        return selected;
    }

    public void setSelected(boolean selected) {
        this.selected = selected;
    }

    @Override
    public String toString() {
        return "MapData{" +
                "objectId='" + objectId + '\'' +
                ", name='" + name + '\'' +
                ", title='" + title + '\'' +
                ", picture='" + picture + '\'' +
                ", buildingId='" + buildingId + '\'' +
                ", token='" + token + '\'' +
                ", floorNumber=" + floorNumber +
                ", floorName='" + floorName + '\'' +
                ", zoom=" + zoom +
                ", angle=" + angle +
                ", powerThreshold=" + powerThreshold +
                ", inToOut=" + inToOut +
                ", outToIn=" + outToIn +
                ", gpsFloorlayer=" + gpsFloorlayer +
                ", navigationZoom=" + navigationZoom +
                ", lat=" + lat +
                ", lng=" + lng +
                ", markerId=" + markerId +
                ", districtName='" + districtName + '\'' +
                ", selected=" + selected +
                '}';
    }
}
